package org.implab.gradle.containers.tasks;

import java.io.IOException;
import java.util.HashSet;
import java.util.Set;

import org.gradle.api.provider.Property;
import org.gradle.api.provider.SetProperty;
import org.gradle.api.tasks.Input;
import org.gradle.api.tasks.TaskAction;

public abstract class TagImage extends DockerCliTask {
    @Input
    public abstract Property<String> getSrcImage();

    @Input
    public abstract SetProperty<String> getTags();

    @Input
    @Deprecated
    public abstract Property<String> getDestImage();

    private Set<String> getImageTags() {
        var tags = new HashSet<>(getTags().get());
        tags.add(getDestImage().get());
        return tags;
    }

    public TagImage() {
        this.setOnlyIf("No tags were specified", self -> getImageTags().size() > 0);
    }

    @TaskAction
    public void run() throws InterruptedException, IOException {
        var tags = getImageTags();
        var src = getSrcImage().get();

        if (tags.size() == 0)
            getLogger().info("No tags were specified");

        for (var tag : tags) {
            getLogger().info("Tag: {}", tag);
            docker().tagImage(src, tag);
        }
    }
}
